.. module:: brownie.parallel

Parallelization
===============

This module provides parallelization utilities.

.. autofunction:: get_cpu_count

.. autoexception:: TimeoutError

.. autoclass:: AsyncResult
   :members:
